Crate hyphae_engine

Crate hyphae_engine 

Embeddable Hyphae facade over durable storage, structured query, and exact provider-neutral retrieval.

Re-exports

pub use proof::MAX_RESULT_PROOF_BYTES;
pub use proof::ProofAnchor;
pub use proof::ProofError;
pub use proof::ProvenOperation;
pub use proof::ProvenResult;
pub use proof::RESULT_PROOF_FORMAT_VERSION;
pub use proof::ResultProof;
pub use proof::ResultProofArtifact;
pub use proof::VerificationLimits;
pub use proof::VerificationReport;
pub use proof::read_result_proof;
pub use proof::verify_result_proof;
pub use proof::write_result_proof;

Modules

proof
Canonical snapshot-witness result proofs and offline verification.

Structs

HyphaeEngine
Embeddable autonomous Hyphae engine.
OpenedEngine
Newly opened embeddable engine and durable recovery evidence.

Enums

DocumentError
Failure while encoding or verifying one canonical structured document.
EngineError
Failure while operating the embeddable Hyphae facade.

Constants

MAX_DOCUMENT_BYTES
Maximum canonical document payload bytes.
MAX_DOCUMENT_DEPTH
Maximum nested array/object depth, with the root at depth zero.
MAX_DOCUMENT_NODES
Maximum values decoded from one document.

Functions

decode_document
Verifies and decodes one canonical binary document.
encode_document
Encodes one structured value into a checksummed canonical binary document.