RetrievalProofError

Enum RetrievalProofError 

pub enum RetrievalProofError {
Show 20 variants Io(Error), Snapshot { source: Box<SnapshotError>, }, Vector(VectorValueError), Retrieval { source: Box<ExactRetrievalError>, }, Lexical { source: Box<LexicalError>, }, Hybrid { source: Box<HybridError>, }, Document { source: Box<DocumentError>, }, Invalid { reason: &'static str, }, UnsupportedVersion { found: u16, supported: u16, }, UnsupportedOperation { found: u16, }, UnsupportedSemantics { found: u16, supported: u16, }, ProofLimitExceeded { actual: u64, maximum: u64, }, LengthOverflow, ChecksumMismatch, DigestMismatch, AnchorMismatch, SnapshotAnchorMismatch, SnapshotFormatMismatch, ReexecutionMismatch, TimedOut,
}
Failure while encoding, reading, or verifying a retrieval proof.

Variants



Io(Error)

Proof file I/O failed.



Snapshot

Snapshot witness verification failed.

Fields

source: Box<SnapshotError>

Underlying snapshot failure.



Vector(VectorValueError)

Canonical vector value is invalid.



Retrieval

Exact-retrieval replay failed.

Fields

source: Box<ExactRetrievalError>

Underlying deterministic retrieval failure.



Lexical

Lexical-retrieval replay failed.

Fields

source: Box<LexicalError>

Underlying deterministic lexical failure.



Hybrid

Hybrid fusion replay failed.

Fields

source: Box<HybridError>

Underlying deterministic hybrid failure.



Document

Canonical durable document decoding failed.

Fields

source: Box<DocumentError>

Underlying canonical document failure.



Invalid

Proof bytes violate the canonical format.

Fields

reason: &'static str

Stable diagnostic reason.



UnsupportedVersion

Proof format is newer than this verifier.

Fields

found: u16

Version found in proof bytes.

supported: u16

Highest supported version.



UnsupportedOperation

Retrieval operation is not supported.

Fields

found: u16

Operation tag found in proof bytes.



UnsupportedSemantics

Retrieval semantics version is not supported.

Fields

found: u16

Semantics version found in proof bytes.

supported: u16

Supported semantics version.



ProofLimitExceeded

Proof file exceeds caller policy.

Fields

actual: u64

Observed proof bytes.

maximum: u64

Configured maximum.



LengthOverflow

A canonical length or count cannot be represented safely.



ChecksumMismatch

Fast accidental-corruption check failed.



DigestMismatch

Canonical proof content digest failed.



AnchorMismatch

Proof anchor did not match caller-pinned trust state.



SnapshotAnchorMismatch

Snapshot metadata does not match the proof anchor.



SnapshotFormatMismatch

Snapshot uses a format that cannot witness durable vectors.



ReexecutionMismatch

Deterministic replay did not reproduce the embedded outcome.



TimedOut

End-to-end cooperative verification deadline expired.