pub struct RetrievalProofAnchor {
pub checkpoint_sequence: u64,
pub checkpoint_digest: Option<[u8; 32]>,
pub snapshot_digest: [u8; 32],
}Expand description
Snapshot and log checkpoint identity trusted by one retrieval proof.
Fields
checkpoint_sequence: u64Materialized commit sequence captured by the snapshot.
checkpoint_digest: Option<[u8; 32]>Commit digest captured by the snapshot, absent only for empty history.
snapshot_digest: [u8; 32]Canonical logical snapshot digest.
Implementations
Sourceimpl RetrievalProofAnchor
impl RetrievalProofAnchor
Sourcepub fn from_snapshot(snapshot: &SnapshotInfo) -> Self
pub fn from_snapshot(snapshot: &SnapshotInfo) -> Self
Creates an anchor from already verified snapshot metadata.