RecoveryLimits

Struct RecoveryLimits 

pub struct RecoveryLimits {
    pub timeout: Duration,
    pub max_directory_entries: u64,
    pub max_log_file_bytes: u64,
    pub max_log_frames: u64,
    pub max_transactions: u64,
    pub max_operations: u64,
    pub max_decoded_operation_bytes: u64,
    pub snapshot: SnapshotReadLimits,
    pub max_lexical_documents: u64,
    pub max_lexical_tokens: u64,
}
Finite policy for one complete open/recovery operation.

Fields

timeout: Duration

Cooperative end-to-end open/recovery timeout.

max_directory_entries: u64

Maximum entries inspected in any owned metadata directory.

max_log_file_bytes: u64

Maximum complete active log segment length.

max_log_frames: u64

Maximum complete frames inspected in the active segment.

max_transactions: u64

Maximum unique committed transactions retained for replay.

max_operations: u64

Maximum operation frames retained across committed transactions.

max_decoded_operation_bytes: u64

Maximum aggregate decoded operation payload bytes retained for replay.

snapshot: SnapshotReadLimits

Snapshot file, logical-record, and decoded-byte limits during restore.

max_lexical_documents: u64

Maximum durable documents inspected while rebuilding one lexical index.

max_lexical_tokens: u64

Maximum normalized tokens retained while rebuilding one lexical index.