Embeddable Hyphae facade over durable storage, structured query, and exact provider-neutral retrieval.
Re-exports
pub use proof::MAX_RESULT_PROOF_BYTES;pub use proof::ProofAnchor;pub use proof::ProofError;pub use proof::ProvenOperation;pub use proof::ProvenResult;pub use proof::RESULT_PROOF_FORMAT_VERSION;pub use proof::ResultProof;pub use proof::ResultProofArtifact;pub use proof::VerificationLimits;pub use proof::VerificationReport;pub use proof::read_result_proof;pub use proof::verify_result_proof;pub use proof::write_result_proof;
Modules
- proof
- Canonical snapshot-witness result proofs and offline verification.
Structs
- Hyphae
Engine - Embeddable autonomous Hyphae engine.
- Opened
Engine - Newly opened embeddable engine and durable recovery evidence.
Enums
- Document
Error - Failure while encoding or verifying one canonical structured document.
- Engine
Error - Failure while operating the embeddable Hyphae facade.
Constants
- MAX_
DOCUMENT_ BYTES - Maximum canonical document payload bytes.
- MAX_
DOCUMENT_ DEPTH - Maximum nested array/object depth, with the root at depth zero.
- MAX_
DOCUMENT_ NODES - Maximum values decoded from one document.
Functions
- decode_
document - Verifies and decodes one canonical binary document.
- encode_
document - Encodes one structured value into a checksummed canonical binary document.