Canonical durable-retrieval proofs and complete offline verification.
Structs
- Exact
Retrieval Proof - Canonical exact-retrieval proof with embedded request and outcome.
- Exact
Retrieval Proof Artifact - Newly created proof and the canonical snapshot witness it references.
- Exact
Retrieval Verification Report - Successful offline exact-retrieval verification evidence.
- Hybrid
Retrieval Proof - Canonical hybrid-retrieval proof with both complete branch executions.
- Hybrid
Retrieval Proof Artifact - Newly created hybrid proof and canonical snapshot witness.
- Hybrid
Retrieval Verification Report - Successful offline hybrid-retrieval verification evidence.
- Lexical
Retrieval Proof - Canonical lexical-retrieval proof with embedded request and outcome.
- Lexical
Retrieval Proof Artifact - Newly created lexical proof and canonical snapshot witness.
- Lexical
Retrieval Verification Report - Successful offline lexical-retrieval verification evidence.
- Retrieval
Proof Anchor - Snapshot and log checkpoint identity trusted by one retrieval proof.
- Retrieval
Verification Limits - Resource limits for complete offline exact-retrieval verification.
Enums
- Retrieval
Proof Error - Failure while encoding, reading, or verifying a retrieval proof.
Constants
- EXACT_
RETRIEVAL_ SEMANTICS_ VERSION - Durable exact-retrieval semantics version bound into proofs.
- HYBRID_
RETRIEVAL_ SEMANTICS_ VERSION - Deterministic hybrid-retrieval semantics version bound into proofs.
- LEXICAL_
RETRIEVAL_ SEMANTICS_ VERSION - Durable lexical-retrieval semantics version bound into proofs.
- MAX_
RETRIEVAL_ PROOF_ BYTES - Hard maximum canonical retrieval-proof file length.
- RETRIEVAL_
PROOF_ FORMAT_ VERSION - Version of the canonical retrieval-proof envelope.
Functions
- read_
exact_ retrieval_ proof - Reads and verifies one canonical exact-retrieval proof under a byte limit.
- read_
hybrid_ retrieval_ proof - Reads and verifies one canonical hybrid-retrieval proof.
- read_
lexical_ retrieval_ proof - Reads and verifies one canonical lexical-retrieval proof.
- verify_
exact_ retrieval_ proof - Verifies an exact-retrieval proof completely offline against a trusted anchor and canonical format-2 snapshot witness.
- verify_
hybrid_ retrieval_ proof - Verifies a hybrid-retrieval proof completely offline.
- verify_
lexical_ retrieval_ proof - Verifies a lexical-retrieval proof completely offline.
- write_
exact_ retrieval_ proof - Writes a canonical exact-retrieval proof to a new synchronized file.
- write_
hybrid_ retrieval_ proof - Writes a canonical hybrid-retrieval proof to a new synchronized file.
- write_
lexical_ retrieval_ proof - Writes a canonical lexical-retrieval proof to a new synchronized file.